  // Load data from CSV file
    d3.csv('data/Global_Map_data.csv').then(function (data) {
        createScatterPlot(data, 'scatterplot');
    });

    // Function to create scatter plot
    function createScatterPlot(data, containerId) {
        // Set up margin, width, and height
        const margin = { top: 40, right: 20, bottom: 60, left: 70 };
        const width = 800 - margin.left - margin.right;
        const height = 400 - margin.top - margin.bottom;

        // Create SVG container
        const svg = d3.select(`#${containerId}`)
            .attr('width', width + margin.left + margin.right)
            .attr('height', height + margin.top + margin.bottom)
            .append('g')
            .attr('transform', `translate(${margin.left},${margin.top})`);

        // Set up scales
        const xScale = d3.scaleLinear()
            .domain([0, d3.max(data, d => +d['People Positive Cases Count'])])
            .range([0, width]);

        const yScale = d3.scaleLinear()
            .domain([0, d3.max(data, d => +d['People Death Count'])])
            .range([height, 0]);

        // Create x-axis
        const xAxis = d3.axisBottom(xScale);
        svg.append('g')
            .attr('transform', `translate(0, ${height})`)
            .call(xAxis);

        // Create y-axis
        const yAxis = d3.axisLeft(yScale);
        svg.append('g')
            .call(yAxis);

        // Create circles for each data point
        svg.selectAll('circle')
            .data(data)
            .enter()
            .append('circle')
            .attr('cx', d => xScale(+d['People Positive Cases Count']))
            .attr('cy', d => yScale(+d['People Death Count']))
            .attr('r', 5) // Set circle radius
            .attr('fill', 'steelblue')
            .on('mouseover', handleMouseOver)
            .on('mouseout', handleMouseOut)
            .on('click', handleZoomClick);

        // Add labels
        svg.append('text')
            .attr('x', width / 2)
            .attr('y', height + margin.top + 20)
            .style('text-anchor', 'middle')
            .text('Cumulative Positive Cases');

        svg.append('text')
            .attr('transform', 'rotate(-90)')
            .attr('x', -height / 2)
            .attr('y', -margin.left + 20)
            .style('text-anchor', 'middle')
            .text('Cumulative Death Count');

        // Zoom
        const zoom = d3.zoom()
            .scaleExtent([0.5, 10])
            .on('zoom', handleZoom);

        svg.call(zoom);

        // Tooltip functions
        function handleMouseOver(d) {
            d3.select(this)
                .attr('fill', 'red'); // Change color on hover

            d3.select('#tooltip')
                .style('opacity', 1)
                .html(`<strong>${d['Country Short Name']}</strong><br>
                        Cumulative Positive Cases: ${d['People Positive Cases Count']}<br>
                        Cumulative Death Count: ${d['People Death Count']}`)
                .style('left', d3.event.pageX + 'px')
                .style('top', d3.event.pageY - 28 + 'px');
        }

        function handleMouseOut(d) {
            d3.select(this)
                .attr('fill', 'steelblue'); // Change color back on mouseout

            d3.select('#tooltip').style('opacity', 0);
        }

        function handleZoom(event) {
            svg.attr('transform', event.transform);
        }

        function handleZoomClick(event, d) {
            // Prevent click event from triggering zoom
            event.stopPropagation();

            // Implement any custom behavior on click
            console.log(`Clicked on ${d['Country Short Name']}`);
        }
    }